==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/fr.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'fr', {
	button: {
		title: 'Propriétés du bouton',
		text: 'Texte (Value)',
		type: 'Type',
		typeBtn: 'Bouton',
		typeSbm: 'Validation (submit)',
		typeRst: 'Remise à zéro'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propriétés de la case à cocher',
		radioTitle: 'Propriétés du bouton Radio',
		value: 'Valeur',
		selected: 'Sélectionné',
		required: 'Requis'
	},
	form: {
		title: 'Propriétés du formulaire',
		menu: 'Propriétés du formulaire',
		action: 'Action',
		method: 'Méthode',
		encoding: 'Encodage'
	},
	hidden: {
		title: 'Propriétés du champ caché',
		name: 'Nom',
		value: 'Valeur'
	},
	select: {
		title: 'Propriétés du menu déroulant',
		selectInfo: 'Informations sur le menu déroulant',
		opAvail: 'Options disponibles',
		value: 'Valeur',
		size: 'Taille',
		lines: 'Lignes',
		chkMulti: 'Permettre les sélections multiples',
		required: 'Requis',
		opText: 'Texte',
		opValue: 'Valeur',
		btnAdd: 'Ajouter',
		btnModify: 'Modifier',
		btnUp: 'Haut',
		btnDown: 'Bas',
		btnSetValue: 'Définir comme valeur sélectionnée',
		btnDelete: 'Supprimer'
	},
	textarea: {
		title: 'Propriétés de la zone de texte',
		cols: 'Colonnes',
		rows: 'Lignes'
	},
	textfield: {
		title: 'Propriétés du champ texte',
		name: 'Nom',
		value: 'Valeur',
		charWidth: 'Taille des caractères',
		maxChars: 'Nombre maximum de caractères',
		required: 'Requis',
		type: 'Type',
		typeText: 'Texte',
		typePass: 'Mot de passe',
		typeEmail: 'E-mail',
		typeSearch: 'Rechercher',
		typeTel: 'Numéro de téléphone',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/forms/lang/fr.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'fr', {
	button: {
		title: 'Propriétés du bouton',
		text: 'Texte',
		type: 'Type',
		typeBtn: 'Bouton',
		typeSbm: 'Validation',
		typeRst: 'Remise à zéro'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propriétés de la case à cocher',
		radioTitle: 'Propriétés du bouton radio',
		value: 'Valeur',
		selected: 'Sélectionné',
		required: 'Requis'
	},
	form: {
		title: 'Propriétés du formulaire',
		menu: 'Propriétés du formulaire',
		action: 'Action',
		method: 'Méthode',
		encoding: 'Encodage'
	},
	hidden: {
		title: 'Propriétés du champ invisible',
		name: 'Nom',
		value: 'Valeur'
	},
	select: {
		title: 'Propriétés du menu déroulant',
		selectInfo: 'Informations sur le menu déroulant',
		opAvail: 'Options disponibles',
		value: 'Valeur',
		size: 'Taille',
		lines: 'lignes',
		chkMulti: 'Permettre les sélections multiples',
		required: 'Requis',
		opText: 'Texte',
		opValue: 'Valeur',
		btnAdd: 'Ajouter',
		btnModify: 'Modifier',
		btnUp: 'Haut',
		btnDown: 'Bas',
		btnSetValue: 'Définir comme valeur sélectionnée',
		btnDelete: 'Supprimer'
	},
	textarea: {
		title: 'Propriétés de la zone de texte',
		cols: 'Colonnes',
		rows: 'Lignes'
	},
	textfield: {
		title: 'Propriétés du champ texte',
		name: 'Nom',
		value: 'Valeur',
		charWidth: 'Largeur des caractères',
		maxChars: 'Nombre maximum de caractères',
		required: 'Requis',
		type: 'Type',
		typeText: 'Texte',
		typePass: 'Mot de passe',
		typeEmail: 'Courriel',
		typeSearch: 'Rechercher',
		typeTel: 'Numéro de téléphone',
		typeUrl: 'URL'
	}
} );
